# PyMillion
Um jogo do milhão sobre python feito em python.

## Instalação
```
$ pip install thePyMillion
```

## Desinstalação
```
$ pip unistall thePyMillion
```

## Como jogar
Para iniciar o jogo, digite: 
```
$ pymillion 
```

## Controles
- Mouse Click